Test Run Failed Tests
setTimeout | 120000 |
storeEval | selenium.browserbot.baseUrl | myBaseUrl
echo | ${myBaseUrl} |
open | ../core/TestRunner.html?test=../tests/dogfood/aut/BaseUrl1TestSuite.html&baseUrl=${myBaseUrl} |
waitForEval | window.htmlTestRunner.testCaseLoaded | true
click | runSuite |
waitForText | testRuns | 1
verifyText | commandPasses | 1
open | ../core/TestRunner.html?test=../tests/dogfood/aut/BaseUrl2TestSuite.html&baseUrl=${myBaseUrl}/../html/ |
waitForEval | window.htmlTestRunner.testCaseLoaded | true
click | runSuite |
waitForText | testRuns | 1
verifyText | commandPasses | 1